.include "system\header.asm"
.include "constants.asm"
.include "system\disclaimer.asm"

.segment "ZEROPAGE"
.include "zero_page.asm" ; reserved vars are defined here

.segment "CODE"
irq_handler:
  jmp main

;;;;;;;;;;;;;;
; RESET
;;;;;;;;;;;;;;

.include "reset_handler.asm" ; ends on a jump to main

;;;;;;;;;;;;;;
; NMI
;;;;;;;;;;;;;;

.include "nmi_handler.asm" ; time sensitive code goes here (movement logic, sounds). ends on RTI

;;;;;;;;;;;;;;
; MAIN
;;;;;;;;;;;;;;

main:  
  lda framedone       ; has this frame been processed yet
  bne main
  
  jsr game_timer
  jsr flip_buffer_order
  jsr read_controller
  jsr state_machine 

  lda #$01
  sta framedone

  jmp main

.include "actors\update_p1.asm"
.include "actors\update_p2.asm"
.include "actors\update_pai.asm"
.include "actors\update_girl.asm"
.include "actors\update_cougar.asm"

;;;;;;;;;;;;;;
; GAME STATE
;;;;;;;;;;;;;;

.include "sm\state_machine.asm"
.include "sm\state_setup_splash.asm"
.include "sm\state_splash.asm"
.include "sm\state_setup_title.asm"
.include "sm\state_title.asm"
.include "sm\state_title_start.asm"
.include "sm\state_setup_game.asm"
.include "sm\state_game.asm"

;;;;;;;;;;;;;;
; UTILS
;;;;;;;;;;;;;;

.include "utils\clear_oam.asm"
.include "utils\clear_nams.asm"
.include "utils\load_nam.asm"
.include "utils\update_scroll.asm"
.include "utils\flicker_chr.asm"

.include "utils\buffer_metasprites.asm"
.include "utils\buffer_priority.asm"
.include "utils\draw_sprite_buffer.asm"
.include "utils\flip_buffer_order.asm" 

.include "utils\clear_pal.asm"
.include "utils\start_fade_in.asm"
.include "utils\fade_pal.asm"   ; this is what is used to properly load the palettes.
.include "utils\start_fade_out.asm"
.include "utils\pal_cycler.asm"
.include "utils\cycle_screen_effects.asm"
.include "utils\transfer_pal.asm"

.include "utils\game_timer.asm" 
.include "utils\read_controllers.asm"
.include "utils\collide_chars.asm"
.include "utils\bank_switch.asm"

.include "famitone2.s"

;;;;;;;;;;;;;;
; RODATA
;;;;;;;;;;;;;;

.segment "RODATA" ; The RODATA segment is a segment that is for read only data

pal_splash:
.incbin "data\pal_splash.dat" , 0, 32
pal_title:
.incbin "data\pal_title.dat" , 0, 32
pal_level1:
.incbin "data\pal_level1.dat" , 0, 32

nam_title:
.incbin "data\nam_title.nam"
nam_level1:
.incbin "data\nam_level1.nam"
nam_level1_part2:
.incbin "data\nam_level1_part2.nam"

obj_create_data:
.include "data\obj_create_data.asm"

.include "metasprites.asm"

sfx_data:
.include "sound\sfx.s"

music_data:
.include "sound\tension.s"

.segment "SAMPLE"
dmc_data:
.incbin "sound\tension.dmc"

;;;;;;;;;;;;;;
; VECTORS
;;;;;;;;;;;;;;

.segment "VECTORS"
.addr nmi_handler, reset_handler, irq_handler

;;;;;;;;;;;;;;
; CHR
;;;;;;;;;;;;;;

.segment "CHR"
.incbin "data\chr_title.chr"
.incbin "data\chr_level1.chr"
.incbin "data\chr_level1_part2.chr"